require("town.nut");

/* Import SuperLib for GameScript */

import("util.superlib", "SuperLib", 38);
Helper <- SuperLib.Helper;


class SyCityGrowth extends GSController 
{
	constructor() 
	{
	}
}

function SyCityGrowth::Start() 
{
	// Read the openttd.cfg Town Growth Rate setting first.
	// If the map is set to disallow town growth at all, this script
	// won't do anything further.
	if (GSGameSettings.IsValid("town_growth_rate")) {
		if (! GSGameSettings.GetValue("town_growth_rate") ) {
			GSLog.Warning("You must set town growth in advanced setting to something other than None. This script is now exiting.");
			return true;
		}
	}

	// If both the min value for pax and mail are set to 0,
	// this script will do no good.  Stop the script.
	local paxRequired = GSController.GetSetting("min_transport_pax").tofloat();
	local mailRequired = GSController.GetSetting("min_transport_mail").tofloat();

	if (paxRequired == 0 && mailRequired == 0) {
		GSLog.Warning("You must set either passenger or mail requirements above 0%. This script is now exiting.");
		return true;
	}
	// OK, we're clear to go.  Take away the ability to fund new
	// buildings from the users, and start the mail loop.
	// Main loop sleeps 28 days between the manage() function executions
	GSGameSettings.SetValue("economy.fund_buildings", 0);

	while (true) {
		this.ManageTowns();
		this.Sleep(72*28);
	}
}

function SyCityGrowth::CreateTownList()
{
	local result = [];

	/* Make a squirrel array of all towns.
	 * For each town, an instance of Town is created
	 * to store the data related to that town
	 */
	local all_towns = GSTownList();
	foreach(t, _ in all_towns)
	{
		result.append(Town(t));
	}

	return result;
}

function SyCityGrowth::ManageTowns() {
	// Create the towns list
	local towns = this.CreateTownList();
	// Set initial time the towns will grow
	foreach (town in towns) {
		town.ManageTown();
	}
	towns = null;
}
